@@ -32,20 +32,25 @@
 
 using namespace Practice;
 
-GuiFrontend::GuiFrontend(QWidget* parent)
-    : AbstractFrontend(parent), m_modeWidget(0), m_lastImage(QStringLiteral("invalid")), m_currentBox(0), m_newBoxIfCorrect(0), m_newBoxIfWrong(0)
+GuiFrontend::GuiFrontend(QWidget *parent)
+    : AbstractFrontend(parent)
+    , m_widget(new ImageWidget())
+    , m_ui(new Ui::PracticeMainWindow())
+    , m_modeWidget(nullptr)
+    , m_resultState(AbstractFrontend::AnswerWrong)
+    , m_feedbackState(AbstractFrontend::AnswerWrong)
+    , m_currentBox(0)
+    , m_newBoxIfCorrect(0)
+    , m_newBoxIfWrong(0)
+    , m_themedBackgroundRenderer(new ThemedBackgroundRenderer(this, QStringLiteral("practicethemecache.bin")))
 {
-    m_widget = new ImageWidget();
     m_widget->setScalingEnabled(false, false);
     m_widget->setKeepAspectRatio(Qt::IgnoreAspectRatio);
     m_widget->setFadingEnabled(false);
 
-    m_ui = new Ui::PracticeMainWindow();
     m_ui->setupUi(m_widget);
     m_ui->centralPracticeWidget->setLayout(new QHBoxLayout());
 
-    m_themedBackgroundRenderer = new ThemedBackgroundRenderer(this, QStringLiteral("practicethemecache.bin"));
-
     connect(Prefs::self(), &Prefs::configChanged, this, &GuiFrontend::setTheme);
     setTheme();
 
